On Sunday 13 January 2008 Sheldon Hearn wrote:
> On Sunday 13 January 2008 10:07:33 Philipp Marek wrote:
> > > > Results tarball (and modified run script) attached.
> >
> > Thank you, that -d helps a lot ...
> >
> > How about r1339? Here's the relevant part:
>
> Uncovers a different problem:
No, I just made an error - modified an argument I shouldn't.

> An error occurred at 15:46:21.084: No such file or directory (2)
>   in waa__find_common_base [waa.c:2233]: chdir(/tmp/fsvs.j2393/)
>
> I should point out that this is fsvsv-1.1.11 patched per r1339.  It's
> not svn trunk.
Ok.

> Full log attached.
Thank you - that helps tremendously.


Please try this *over* the other patch - it substitutes the lines:


Regards,

Phil


Index: waa.c
===================================================================
--- waa.c       (Revision 1339)
+++ waa.c       (Arbeitskopie)
@@ -343,6 +343,7 @@ int waa__get_waa_directory(char *path,
        int status, len, plen, wdlen;
        char *cp;
        unsigned char digest[APR_MD5_DIGESTSIZE], *p2dig;
+       const char root[]= { PATH_SEPARATOR, 0};

        status=0;
        cp=NULL;
@@ -387,12 +388,9 @@ int waa__get_waa_directory(char *path,
                 * That is achieved in waa__init(); the softroot path gets 
normalized
                 * there. */
                /* In case both the argument and the softroot are identical,
                 * we end up with *path==0. Change that to "/". */
*/
                if (!*path)
-               {
-                       path--;
-                       *path=PATH_SEPARATOR;
-               }
+                       path=(char*)root;

                plen=strlen(path);
        }
@@ -387,12 +388,9 @@ int waa__get_waa_directory(char *path,
                 * there. */
                /* In case both the argument and the softroot are identical,
-                * we end up with *path==0. Change that to "/". */
+                * we end up with *path==0. Change that to the root directory. 
*/
                if (!*path)


-- 
Versioning your /etc, /home or even your whole installation?
             Try fsvs (fsvs.tigris.org)!

---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]

Reply via email to